package ru.ulstu.paper.service;

import org.springframework.stereotype.Service;
import ru.ulstu.core.util.DateUtils;
import ru.ulstu.paper.model.Paper;
import ru.ulstu.user.model.User;
import ru.ulstu.user.service.MailService;

import java.util.Date;
import java.util.stream.Collectors;

@Service
public class PaperNotificationService {
    private final static int DAYS_TO_DEADLINE_NOTIFICATION = 7;

    private final MailService mailService;

    private final PaperService paperService;

    public PaperNotificationService(MailService mailService,
                                    PaperService paperService) {
        this.mailService = mailService;
        this.paperService = paperService;
    }

    public void sendDeadlineNotifications(boolean isDeadlineBeforeWeek) {
        Date now = DateUtils.addDays(new Date(), DAYS_TO_DEADLINE_NOTIFICATION);
        paperService
                .findAll()
                .stream()
                .filter(paper -> needToSendDeadlineNotification(paper, now, isDeadlineBeforeWeek))
                .map(paper -> sendMessageDeadline(paper))
                .collect(Collectors.toList());
    }

    private boolean needToSendDeadlineNotification(Paper paper, Date compareDate, boolean isDeadlineBeforeWeek) {
        return (paper.getDeadlineDate() != null)
                && (compareDate.after(paper.getDeadlineDate()) && isDeadlineBeforeWeek
                || compareDate.before(paper.getDeadlineDate()) && !isDeadlineBeforeWeek);
    }

    private Paper sendMessageDeadline(Paper paper) {
        for (User user : paper.getAuthors()) {
            mailService.sendEmail(user.getEmail(), "Приближается срок сдачи статьи",
                    "Срок сдачи статьи " + paper.getTitle() + " " + paper.getDeadlineDate().toString());
        }
        return paper;
    }
}
